spannertools.make_solid_text_spanner_below_with_nib_at_right
============================================================

.. autofunction:: abjad.tools.spannertools.make_solid_text_spanner_below_with_nib_at_right
